@@ -128,7 +128,6 @@ class Client:
             )
         
         return self.get_item(items_fond[0]['uuid'], vault_id)
-#         return self.__deserialize(items_fond, "list[OPSummaryItem]")[0]
 
     def get_items(self, vault_id: str):
         """Returns a list of item summaries for the specified vault
@@ -168,9 +167,18 @@ class Client:
         if 'vaultUuid' in item:
             item['vaultUuid'] = {'id': item['vaultUuid']}
 
+        self.__organise_item_urls(item)
+        self.__organise_item_field(item)
+        self.__organise_item_section(item)
+        return item
+    
+    def __organise_item_urls(self, item):
         if 'URLs' in item and 'url' in item:
             for i, url in enumerate(item['URLs']):
                 item['URLs'][i]['primary'] = True if url['u'] == item['url'] else False
+        return item
+    
+    def __organise_item_field(self, item):
         if 'fields' in item:
             type_field = {'T': 'STRING', 'P': 'CONCEALED'}
             for i, old_field in enumerate(item['fields']):
@@ -204,6 +212,9 @@ class Client:
                 "value": item['password']
             }
             item['fields'].append(field)
+        return item
+    
+    def __organise_item_section(self, item):
         if 'sections' in item:
             for i, old_section in enumerate(item['sections']):
                 section = {
@@ -211,26 +222,34 @@ class Client:
                     'label': old_section['title']
                 }
                 if 'fields' in old_section:
-                    for old_field in old_section['fields']:
-                        type = None
-                        if old_field['n'].startswith('TOTP'):
-                            type = 'OTP'
-                        elif old_field['k'] in list(Field.types.values()):
-                            type = list(Field.types.keys())[list(Field.types.values()).index(old_field['k'])]
-                        else:
-                            continue
-
-                        field = {
-                            'id' : old_field['n'],
-                            'section':{'id': old_section['name']},
-                            'type': type ,
-                            'label': old_field['t'],
-                            'value': old_field['v'] if old_field['k'] != 'address' else json.dumps(old_field['v']),
-                        }
-                        item['fields'].append(field)
+                    fields = self.__organise_item_section_field( old_section)
+                    item['fields'].extend(fields)
                 item['sections'][i] = section
         return item
-
+    
+    def __organise_item_section_field(self, old_section):
+        fields: list = []
+        for old_field in old_section['fields']:
+#                         field = self.__organise_item_section_field( old_field, old_section)
+            type_field = None
+            if old_field['n'].startswith('TOTP'):
+                type_field = 'OTP'
+            elif old_field['k'] in list(Field.types.values()):
+                type_field = list(Field.types.keys())[list(Field.types.values()).index(old_field['k'])]
+            else:
+                continue
+    
+            field = {
+                'id' : old_field['n'],
+                'section':{'id': old_section['name']},
+                'type': type_field ,
+                'label': old_field['t'],
+                'value': old_field['v'] if old_field['k'] != 'address' else json.dumps(old_field['v']),
+            }
+            fields.append(field)
+        return fields
+        
+            
     def delete_item(self, item_id: str, vault_id: str):
         """Deletes a specified item from a specified vault
 
@@ -275,7 +294,7 @@ class Client:
 
         encoded_item = {}
 
-        self._create_item_field(encoded_item, serialized_body['fields'], serialized_body['templateUuid'])
+        self._create_item_fields(encoded_item, serialized_body['fields'], serialized_body['templateUuid'])
         for section in serialized_body['sections']:
             if section['id'] in encoded_item['sections']:
                 encoded_item['sections'][section['id']]['title'] = section['label']
@@ -297,14 +316,13 @@ class Client:
         if primary_url:
             cmd = f'{cmd} --url "{self._escape_quote(primary_url)}"'
 
-        logger
         if 'tags' in serialized_body and serialized_body['tags']:
             cmd = '{cmd} --tags "{tags}"'.format(cmd=cmd, tags=self._escape_quote(",".join(serialized_body['tags'])))
 
         rc, stdout, stderr = self._process_raise(cmd=cmd,tail_stdout=0)
         return self.deserialize(stdout.strip(), "OPItem")
 
-    def _create_item_field(self, encoded_item: dict, fields: dict, template_uuid: str):
+    def _create_item_fields(self, encoded_item: dict, fields: dict, template_uuid: str):
         logger.debug(f'{inspect.stack()[0][3]} : start')
         encoded_item['fields'] = []
         encoded_item['sections'] = {}
@@ -312,17 +330,25 @@ class Client:
             if 'purpose' in field:
                 self._create_item_field_purpose(encoded_item, field, template_uuid )
             elif 'section' in field:
-                if not 'id' in field['section']:
-                    continue
-                encoded_field = {
-                    "k": Field.types[field['type']] if field['type'] != 'OTP' else 'concealed',
-                    "n": str(uuid.uuid4()) if field['type'] != 'OTP' else f'TOTP_{str(uuid.uuid4())}',
-                    "t": field['label'],
-                    "v": json.loads(field['value']) if field['type'] == 'ADDRESS' else int(field['value']) if field['type'] in ['DATE', 'MONTH_YEAR'] else field['value']
-                    }
-                if not field['section']['id'] in encoded_item['sections']:
-                    encoded_item['sections'][field['section']['id']] = {'fields':[]}
-                encoded_item['sections'][field['section']['id']]['fields'].append(encoded_field)
+                self._create_item_field_custom(encoded_item, field, template_uuid)
+    
+    def _create_item_field_custom(self, encoded_item: dict, field: dict, template_uuid: str):
+        if not 'id' in field['section']:
+            return
+        encoded_field = {
+            "k": Field.types[field['type']] if field['type'] != 'OTP' else 'concealed',
+            "n": str(uuid.uuid4()) if field['type'] != 'OTP' else f'TOTP_{str(uuid.uuid4())}',
+            "t": field['label'],
+            }
+        if field['type'] == 'ADDRESS':
+            encoded_field['v'] = json.loads(field['value'])
+        elif field['type'] in ['DATE', 'MONTH_YEAR']:
+            encoded_field['v'] = int(field['value'])
+        else:
+            encoded_field['v'] = field['value']
+        if not field['section']['id'] in encoded_item['sections']:
+            encoded_item['sections'][field['section']['id']] = {'fields':[]}
+        encoded_item['sections'][field['section']['id']]['fields'].append(encoded_field)
     
     def _create_item_field_purpose(self, encoded_item: dict, field: dict, template_uuid: str):
         logger.debug(f'{inspect.stack()[0][3]} : start')
